import { Component, Host, h, Prop, State, Event } from '@stencil/core';
import { isValidDomain } from '../../helpers/isValidDomain';
export class EbanxCookiesDisclaimer {
    constructor() {
        this.localStorageKey = `${window.location.host}_cookies_acceptance`;
        /**
         * Policy Privacy link
         * @default 'https://www.ebanx.com/br/politica-de-privacidade/'
         */
        this.link = 'https://www.ebanx.com/br/politica-de-privacidade/';
        this.hasAccepted = localStorage.getItem(this.localStorageKey) !== null;
        this.shouldRender = isValidDomain();
    }
    acceptCookiesUsage() {
        localStorage.setItem(this.localStorageKey, JSON.stringify({
            accepted: true,
            timestamp: new Date().getTime()
        }));
        this.hasAccepted = true;
        this.acceptedCookies.emit(this.hasAccepted);
        return this.hasAccepted;
    }
    render() {
        if (!this.shouldRender) {
            return null;
        }
        return (h(Host, null,
            h("div", { class: "ebx-cookie-notice" }, this.hasAccepted ? null : (h("div", { class: "ebx-cookies-disclaimer" },
                h("div", { class: "ebx-cookies-disclaimer__text" },
                    h("p", null,
                        "Esta p\u00E1gina utiliza cookies para coletar informa\u00E7\u00F5es que podem melhorar a experi\u00EAncia do usu\u00E1rio em nosso site. Por isso, \u00E9 preciso aceitar nossa",
                        ' ',
                        h("a", { href: this.link, target: "_blank", rel: "noopener noreferrer" }, "Pol\u00EDtica de Privacidade"),
                        ' ',
                        "para continuar a navega\u00E7\u00E3o.")),
                h("div", { class: "ebx-cookies-disclaimer__action" },
                    h("button", { onClick: () => this.acceptCookiesUsage() }, "Aceitar")))))));
    }
    static get is() { return "ebanx-cookies-disclaimer"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() { return {
        "$": ["ebanx-cookies-disclaimer.css"]
    }; }
    static get styleUrls() { return {
        "$": ["ebanx-cookies-disclaimer.css"]
    }; }
    static get properties() { return {
        "link": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [{
                        "text": "'https://www.ebanx.com/br/politica-de-privacidade/'",
                        "name": "default"
                    }],
                "text": "Policy Privacy link"
            },
            "attribute": "link",
            "reflect": false,
            "defaultValue": "'https://www.ebanx.com/br/politica-de-privacidade/'"
        }
    }; }
    static get states() { return {
        "hasAccepted": {},
        "shouldRender": {}
    }; }
    static get events() { return [{
            "method": "acceptedCookies",
            "name": "acceptedCookies",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": "Fires when cookie acceptance state changes"
            },
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            }
        }]; }
}
