import { Component, Host, h, Prop, State } from '@stencil/core';
import { content } from '../../data/trackForm';
export class EbanxTrackForm {
    constructor() {
        /**
         * Changes component language and
         * which version of EBANX Track website to send users to
         **/
        this.locale = 'pt';
        /**
         * If true, will not render the form title
         *
         * @default false
         */
        this.hideTitle = false;
        this.formAction = `https://track.ebanx.com/${this.locale}/t/`;
        this.trackingCodeInputChange = this.trackingCodeInputChange.bind(this);
    }
    componentWillRender() {
        if (!content[this.locale]) {
            this.locale = 'pt';
        }
    }
    trackingCodeInputChange(event) {
        const input = event.target;
        const sanitizedTrackingCode = input.value.toUpperCase().trim().replace(/\W/g, '');
        input.value = sanitizedTrackingCode;
    }
    render() {
        return (h(Host, null,
            h("div", { class: "ebx-track-form" },
                h("div", { class: "ebx-track-form__container" },
                    !this.hideTitle && (h("div", { class: "ebx-track-form__title-container" },
                        h("h3", { class: "ebx-track-form__title" },
                            content[this.locale].title,
                            ' ',
                            h("img", { class: "ebx-track-form__title-logo", src: "https://unpkg.com/@ebanx/global-components/dist/global-components/assets/track-logo--color.svg", alt: "Track Logo" })))),
                    h("form", { class: "ebx-track-form__form", method: "GET", action: this.formAction, target: "_blank" },
                        h("div", { class: "ebx-track-form__input-group" },
                            h("input", { class: "ebx-track-form__input", type: "text", name: "trackingCode", placeholder: content[this.locale].placeholder, onInput: this.trackingCodeInputChange, required: true }),
                            h("button", { type: "submit", class: "ebx-track-form__button", title: content[this.locale].buttonTitle },
                                h("img", { src: "https://unpkg.com/@ebanx/global-components/dist/global-components/assets/search--blue.svg", alt: content[this.locale].buttonTitle }))),
                        h("input", { type: "hidden", name: "utm_source", value: window.location.href }),
                        h("input", { type: "hidden", name: "utm_medium", value: "gc-form" }))))));
    }
    static get is() { return "ebanx-track-form"; }
    static get encapsulation() { return "shadow"; }
    static get originalStyleUrls() { return {
        "$": ["ebanx-track-form.css"]
    }; }
    static get styleUrls() { return {
        "$": ["ebanx-track-form.css"]
    }; }
    static get properties() { return {
        "locale": {
            "type": "string",
            "mutable": true,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [],
                "text": "Changes component language and\nwhich version of EBANX Track website to send users to"
            },
            "attribute": "locale",
            "reflect": false,
            "defaultValue": "'pt'"
        },
        "hideTitle": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": true,
            "docs": {
                "tags": [{
                        "text": "false",
                        "name": "default"
                    }],
                "text": "If true, will not render the form title"
            },
            "attribute": "hide-title",
            "reflect": false,
            "defaultValue": "false"
        }
    }; }
    static get states() { return {
        "formAction": {}
    }; }
}
