import { attachShadow, createEvent, h, Host, proxyCustomElement } from '@stencil/core/internal/client';
export { setAssetPath } from '@stencil/core/internal/client';

const domains = [
    'ebanx.com',
    'ebanxbeep.com',
    'ebanxgo.com',
    'ebanxpay.com',
    'carreiras.ebanx.com',
    'ebanx.uk'
];

const isValidDomain = (domain = window.location.host) => {
    const isLocal = domain.includes('localhost:');
    const matches = domains.filter((accepted) => {
        return domain.includes(accepted);
    });
    const isValid = matches.length > 0;
    if (isLocal)
        return isLocal;
    return isValid;
};

const ebanxCookiesDisclaimerCss = "*{-webkit-box-sizing:border-box;box-sizing:border-box;line-height:1.4}.ebx-cookies-disclaimer{position:fixed;bottom:0;left:0;display:block;width:100%;padding:32px;background-color:white;border-radius:10px;-webkit-box-shadow:2px 4px 8px rgba(0, 0, 0, 0.2);box-shadow:2px 4px 8px rgba(0, 0, 0, 0.2);z-index:101}p{margin:0;font-family:'Gilroy', sans-serif;font-size:14px;font-weight:400;color:#333f48;line-height:1.7}a{color:#0051ff}button{position:relative;display:inline-block;width:80%;max-width:140px;padding:14px;background-color:#0051ff;border:none;border-radius:2px;font-family:'Open Sans', sans-serif;font-size:14px;font-weight:bold;color:white;letter-spacing:0.8px;line-height:1;text-align:center;text-transform:uppercase;cursor:pointer;-webkit-transition:all ease-in-out 210ms;transition:all ease-in-out 210ms}button:hover{background-color:#0040ca}.ebx-cookies-disclaimer__action{margin-top:24px}@media screen and (min-width: 768px){.ebx-cookies-disclaimer{bottom:48px;left:48px;max-width:432px}button{max-width:160px;padding:12px}}";

const EbanxCookiesDisclaimer = class extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        attachShadow(this);
        this.acceptedCookies = createEvent(this, "acceptedCookies", 7);
        this.localStorageKey = `${window.location.host}_cookies_acceptance`;
        /**
         * Policy Privacy link
         * @default 'https://www.ebanx.com/br/politica-de-privacidade/'
         */
        this.link = 'https://www.ebanx.com/br/politica-de-privacidade/';
        this.hasAccepted = localStorage.getItem(this.localStorageKey) !== null;
        this.shouldRender = isValidDomain();
    }
    acceptCookiesUsage() {
        localStorage.setItem(this.localStorageKey, JSON.stringify({
            accepted: true,
            timestamp: new Date().getTime()
        }));
        this.hasAccepted = true;
        this.acceptedCookies.emit(this.hasAccepted);
        return this.hasAccepted;
    }
    render() {
        if (!this.shouldRender) {
            return null;
        }
        return (h(Host, null, h("div", { class: "ebx-cookie-notice" }, this.hasAccepted ? null : (h("div", { class: "ebx-cookies-disclaimer" }, h("div", { class: "ebx-cookies-disclaimer__text" }, h("p", null, "Esta p\u00E1gina utiliza cookies para coletar informa\u00E7\u00F5es que podem melhorar a experi\u00EAncia do usu\u00E1rio em nosso site. Por isso, \u00E9 preciso aceitar nossa", ' ', h("a", { href: this.link, target: "_blank", rel: "noopener noreferrer" }, "Pol\u00EDtica de Privacidade"), ' ', "para continuar a navega\u00E7\u00E3o.")), h("div", { class: "ebx-cookies-disclaimer__action" }, h("button", { onClick: () => this.acceptCookiesUsage() }, "Aceitar")))))));
    }
    static get style() { return ebanxCookiesDisclaimerCss; }
};

const ebanxLogoCss = ":host{position:relative;display:block}*{-webkit-box-sizing:border-box;box-sizing:border-box}";

const EbanxLogo = class extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        attachShadow(this);
        /** Logo Width */
        this.width = 145;
        /** Logo Height */
        this.height = 28;
        /**
         * If true, renders only the icon, with no text
         * @default false
         */
        this.icon = false;
        this.shouldRender = isValidDomain();
    }
    render() {
        if (!this.shouldRender) {
            return null;
        }
        return (h(Host, null, h("svg", { width: this.width, height: this.height, viewBox: this.icon ? '0 0 28 28' : '0 0 145 28', fill: "none", "aria-labelledby": "logoTitle logoDesc", role: "img" }, h("title", { id: "logoTitle" }, "EBANX"), h("desc", { id: "logoDesc" }, "EBANX's logo, contained by triangles creating the E letter shape and writing with custom typography the word ebanx."), this.icon ? (h("g", null, h("mask", { id: "mask0", "mask-type": "alpha", maskUnits: "userSpaceOnUse", x: "0", y: "0", width: "17", height: "28" }, h("path", { "fill-rule": "evenodd", "clip-rule": "evenodd", d: "M0 0.440552H16.8807V27.3332H0V0.440552Z", fill: "white" })), h("g", { mask: "url(#mask0)" }, h("path", { "fill-rule": "evenodd", "clip-rule": "evenodd", d: "M0.377 0.492228L16.7957 13.7099C16.9091 13.8014 16.9091 13.9722 16.7957 14.0637L0.377 27.2814C0.226304 27.403 0 27.2967 0 27.1045V0.669097C0 0.476892 0.226304 0.370566 0.377 0.492228Z", fill: "white" })), h("mask", { id: "mask1", "mask-type": "alpha", maskUnits: "userSpaceOnUse", x: "2", y: "0", width: "20", height: "10" }, h("path", { "fill-rule": "evenodd", "clip-rule": "evenodd", d: "M2.56396 0.440552H21.6687V9.33245H2.56396V0.440552Z", fill: "white" })), h("g", { mask: "url(#mask1)" }, h("path", { "fill-rule": "evenodd", "clip-rule": "evenodd", d: "M21.4575 0.44043H2.56396L13.6078 9.33248L21.6123 0.79008C21.7371 0.656661 21.6413 0.44043 21.4575 0.44043Z", fill: "white" })), h("path", { "fill-rule": "evenodd", "clip-rule": "evenodd", d: "M21.4575 27.3332H2.56396L13.6078 18.4412L21.6123 26.9831C21.7371 27.117 21.6413 27.3332 21.4575 27.3332Z", fill: "white" }))) : (h("g", null, h("mask", { id: "mask0", "mask-type": "alpha", maskUnits: "userSpaceOnUse", x: "0", y: "0", width: "17", height: "28" }, h("path", { "fill-rule": "evenodd", "clip-rule": "evenodd", d: "M0 0.440552H16.8807V27.3332H0V0.440552Z", fill: "white" })), h("g", { mask: "url(#mask0)" }, h("path", { "fill-rule": "evenodd", "clip-rule": "evenodd", d: "M0.377 0.492228L16.7957 13.7099C16.9091 13.8014 16.9091 13.9722 16.7957 14.0637L0.377 27.2814C0.226304 27.403 0 27.2967 0 27.1045V0.669097C0 0.476892 0.226304 0.370566 0.377 0.492228Z", fill: "white" })), h("mask", { id: "mask1", "mask-type": "alpha", maskUnits: "userSpaceOnUse", x: "2", y: "0", width: "20", height: "10" }, h("path", { "fill-rule": "evenodd", "clip-rule": "evenodd", d: "M2.56396 0.440552H21.6687V9.33245H2.56396V0.440552Z", fill: "white" })), h("g", { mask: "url(#mask1)" }, h("path", { "fill-rule": "evenodd", "clip-rule": "evenodd", d: "M21.4575 0.44043H2.56396L13.6078 9.33248L21.6123 0.79008C21.7371 0.656661 21.6413 0.44043 21.4575 0.44043Z", fill: "white" })), h("path", { "fill-rule": "evenodd", "clip-rule": "evenodd", d: "M21.4575 27.3332H2.56396L13.6078 18.4412L21.6123 26.9831C21.7371 27.117 21.6413 27.3332 21.4575 27.3332Z", fill: "white" }), h("mask", { id: "mask2", "mask-type": "alpha", maskUnits: "userSpaceOnUse", x: "48", y: "0", width: "21", height: "28" }, h("path", { "fill-rule": "evenodd", "clip-rule": "evenodd", d: "M48.1763 0.440552H68.2199V27.3333H48.1763V0.440552Z", fill: "white" })), h("g", { mask: "url(#mask2)" }, h("path", { "fill-rule": "evenodd", "clip-rule": "evenodd", d: "M62.8798 18.9382C62.7752 17.2901 61.3247 16.0382 59.6525 16.0382H53.5475V22.3774H59.7354C61.6468 22.3774 63.0051 20.9098 62.8798 18.9382ZM53.5475 5.57783V11.0894C53.5475 11.2126 53.649 11.3128 53.7738 11.3128H58.9182C60.6887 11.3128 61.9803 9.89376 61.8244 8.05657C61.6954 6.53528 60.3444 5.39636 58.7975 5.39636H53.7308C53.6298 5.39636 53.5475 5.47764 53.5475 5.57783ZM68.2199 19.5342C68.2199 24.1446 64.4442 27.3333 59.7354 27.3333H48.3974C48.2757 27.3333 48.1763 27.2352 48.1763 27.1151V0.654616C48.1763 0.536021 48.2736 0.44043 48.3933 0.44043H58.9182C63.5105 0.44043 67.2075 3.51418 67.2075 8.00903C67.2075 10.314 66.235 12.1195 64.6389 13.3877C66.8186 14.6166 68.2199 16.7298 68.2199 19.5342Z", fill: "white" })), h("mask", { id: "mask3", "mask-type": "alpha", maskUnits: "userSpaceOnUse", x: "69", y: "0", width: "26", height: "28" }, h("path", { "fill-rule": "evenodd", "clip-rule": "evenodd", d: "M69.3928 0.440552H94.9914V27.3334H69.3928V0.440552Z", fill: "white" })), h("g", { mask: "url(#mask3)" }, h("path", { "fill-rule": "evenodd", "clip-rule": "evenodd", d: "M85.8386 17.2728L82.3845 7.11406C82.3228 6.93208 82.0618 6.93208 82.0002 7.11406L78.5456 17.2728C78.5016 17.4022 78.5995 17.5366 78.7377 17.5366H85.6465C85.7847 17.5366 85.8826 17.4022 85.8386 17.2728ZM87.4558 22.4925H76.8895C76.8025 22.4925 76.7248 22.5477 76.6974 22.6295L75.1547 27.1965C75.1272 27.2782 75.0501 27.3335 74.9625 27.3335H69.596C69.4557 27.3335 69.3583 27.197 69.4044 27.0671L78.7973 0.574482C78.8263 0.494226 78.9024 0.440552 78.9889 0.440552H85.3565C85.4424 0.440552 85.5196 0.494226 85.5475 0.573971L94.9798 27.0666C95.0259 27.197 94.9285 27.3335 94.7882 27.3335H89.3828C89.2958 27.3335 89.2181 27.2782 89.1907 27.1965L87.648 22.6295C87.6205 22.5477 87.5434 22.4925 87.4558 22.4925Z", fill: "white" })), h("mask", { id: "mask4", "mask-type": "alpha", maskUnits: "userSpaceOnUse", x: "97", y: "0", width: "22", height: "28" }, h("path", { "fill-rule": "evenodd", "clip-rule": "evenodd", d: "M97.7212 0.440552H118.854V27.3332H97.7212V0.440552Z", fill: "white" })), h("g", { mask: "url(#mask4)" }, h("path", { "fill-rule": "evenodd", "clip-rule": "evenodd", d: "M118.854 0.65705V27.1165C118.854 27.2361 118.757 27.3332 118.635 27.3332H114.882C114.81 27.3332 114.744 27.299 114.703 27.2407L103.092 10.8905V27.1165C103.092 27.2361 102.994 27.3332 102.873 27.3332H97.9408C97.8201 27.3332 97.7212 27.2361 97.7212 27.1165V0.65705C97.7212 0.537433 97.8201 0.440308 97.9408 0.440308H101.694C101.766 0.440308 101.832 0.475068 101.873 0.532321L113.484 16.8447V0.65705C113.484 0.537433 113.582 0.440308 113.703 0.440308H118.635C118.757 0.440308 118.854 0.537433 118.854 0.65705Z", fill: "white" })), h("mask", { id: "mask5", "mask-type": "alpha", maskUnits: "userSpaceOnUse", x: "122", y: "0", width: "23", height: "28" }, h("path", { "fill-rule": "evenodd", "clip-rule": "evenodd", d: "M122.063 0.440552H144.485V27.3333H122.063V0.440552Z", fill: "white" })), h("g", { mask: "url(#mask5)" }, h("path", { "fill-rule": "evenodd", "clip-rule": "evenodd", d: "M138.482 27.2234L133.45 18.8978C133.362 18.7516 133.148 18.7516 133.06 18.8978L128.028 27.2234C127.987 27.2914 127.913 27.3333 127.833 27.3333H122.291C122.115 27.3333 122.005 27.1432 122.095 26.9929L130.15 13.6561C130.193 13.585 130.193 13.4966 130.15 13.426L122.524 0.780367C122.434 0.63059 122.543 0.44043 122.719 0.44043H128.261C128.341 0.44043 128.415 0.482347 128.456 0.550334L133.059 8.18334C133.148 8.33005 133.362 8.33005 133.451 8.18334L138.054 0.550334C138.095 0.482347 138.169 0.44043 138.249 0.44043H143.79C143.967 0.44043 144.076 0.631101 143.986 0.780367L136.36 13.3872C136.317 13.4583 136.317 13.5472 136.36 13.6177L144.452 26.9929C144.544 27.1427 144.434 27.3333 144.257 27.3333H138.678C138.597 27.3333 138.523 27.2914 138.482 27.2234Z", fill: "white" })), h("mask", { id: "mask6", "mask-type": "alpha", maskUnits: "userSpaceOnUse", x: "27", y: "0", width: "18", height: "28" }, h("path", { "fill-rule": "evenodd", "clip-rule": "evenodd", d: "M27.5491 0.440552H44.4012V27.3426H27.5491V0.440552Z", fill: "white" })), h("g", { mask: "url(#mask6)" }, h("path", { "fill-rule": "evenodd", "clip-rule": "evenodd", d: "M34.1642 22.2481C33.463 22.1581 32.9198 21.5733 32.9198 20.8566V16.4379C32.9198 16.3234 33.0135 16.2304 33.13 16.2304H43.0226C43.1392 16.2304 43.2334 16.1374 43.2334 16.0229V11.4437C43.2334 11.3292 43.1392 11.2361 43.0226 11.2361H33.13C33.0135 11.2361 32.9198 11.1431 32.9198 11.0286V5.71943C32.9198 5.60441 33.0135 5.51189 33.13 5.51189H43.9962C44.1122 5.51189 44.2065 5.41886 44.2065 5.30435V0.647971C44.2065 0.533465 44.1122 0.44043 43.9962 0.44043H27.7593C27.6428 0.44043 27.5491 0.533465 27.5491 0.647971V16.8489V22.3171C27.5491 25.0923 29.8282 27.3425 32.6401 27.3425H44.4012V22.2481H34.1642Z", fill: "white" })))))));
    }
    static get style() { return ebanxLogoCss; }
};

const content = {
    en: {
        placeholder: 'Enter your tracking number',
        title: 'Track your orders with',
        buttonTitle: 'Track'
    },
    es: {
        placeholder: 'Ingresa tu código de rastreo',
        title: 'Rastrea tus paquetes con',
        buttonTitle: 'Rastrear'
    },
    pt: {
        placeholder: 'Digite seu código de rastreio',
        title: 'Rastreie suas encomendas com o',
        buttonTitle: 'Rastrear'
    }
};

const ebanxTrackFormCss = ".ebx-track-form__container{-webkit-box-sizing:border-box;box-sizing:border-box;width:100%;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column}.ebx-track-form__title-container{display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center}.ebx-track-form__title{color:#00a3e0;font-family:'Gilroy', sans-serif;font-weight:700;font-size:24px;letter-spacing:0.4px;text-align:center;margin:0;padding-bottom:20px}.ebx-track-form__title-logo{vertical-align:middle}.ebx-track-form__form{width:100%;display:-webkit-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-orient:vertical;-webkit-box-direction:normal;-ms-flex-direction:column;flex-direction:column}.ebx-track-form__input-group{position:relative;max-width:480px;width:100%}.ebx-track-form__input{border:2px solid #9f9faf;-webkit-box-sizing:border-box;box-sizing:border-box;border-radius:6px;padding:16px;font-family:'Gilroy', sans-serif;font-size:16px;font-weight:700;width:100%;outline:none}.ebx-track-form__button{position:absolute;top:50%;right:16px;margin:0;padding:0;background-color:transparent;border:none;-webkit-transform:translateY(-50%);-ms-transform:translateY(-50%);transform:translateY(-50%);cursor:pointer}@media screen and (max-width: 991px){.ebx-track-form__container{padding:0 16px}.ebx-track-form__input-group{width:100%}}";

const EbanxTrackForm = class extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        attachShadow(this);
        /**
         * Changes component language and
         * which version of EBANX Track website to send users to
         **/
        this.locale = 'pt';
        /**
         * If true, will not render the form title
         *
         * @default false
         */
        this.hideTitle = false;
        this.formAction = `https://track.ebanx.com/${this.locale}/t/`;
        this.trackingCodeInputChange = this.trackingCodeInputChange.bind(this);
    }
    componentWillRender() {
        if (!content[this.locale]) {
            this.locale = 'pt';
        }
    }
    trackingCodeInputChange(event) {
        const input = event.target;
        const sanitizedTrackingCode = input.value.toUpperCase().trim().replace(/\W/g, '');
        input.value = sanitizedTrackingCode;
    }
    render() {
        return (h(Host, null, h("div", { class: "ebx-track-form" }, h("div", { class: "ebx-track-form__container" }, !this.hideTitle && (h("div", { class: "ebx-track-form__title-container" }, h("h3", { class: "ebx-track-form__title" }, content[this.locale].title, ' ', h("img", { class: "ebx-track-form__title-logo", src: "https://unpkg.com/@ebanx/global-components/dist/global-components/assets/track-logo--color.svg", alt: "Track Logo" })))), h("form", { class: "ebx-track-form__form", method: "GET", action: this.formAction, target: "_blank" }, h("div", { class: "ebx-track-form__input-group" }, h("input", { class: "ebx-track-form__input", type: "text", name: "trackingCode", placeholder: content[this.locale].placeholder, onInput: this.trackingCodeInputChange, required: true }), h("button", { type: "submit", class: "ebx-track-form__button", title: content[this.locale].buttonTitle }, h("img", { src: "https://unpkg.com/@ebanx/global-components/dist/global-components/assets/search--blue.svg", alt: content[this.locale].buttonTitle }))), h("input", { type: "hidden", name: "utm_source", value: window.location.href }), h("input", { type: "hidden", name: "utm_medium", value: "gc-form" }))))));
    }
    static get style() { return ebanxTrackFormCss; }
};

const EbanxCookiesDisclaimer$1 = /*@__PURE__*/proxyCustomElement(EbanxCookiesDisclaimer, [1,"ebanx-cookies-disclaimer",{"link":[1],"hasAccepted":[32],"shouldRender":[32]}]);
const EbanxLogo$1 = /*@__PURE__*/proxyCustomElement(EbanxLogo, [1,"ebanx-logo",{"width":[2],"height":[2],"icon":[4],"shouldRender":[32]}]);
const EbanxTrackForm$1 = /*@__PURE__*/proxyCustomElement(EbanxTrackForm, [1,"ebanx-track-form",{"locale":[1025],"hideTitle":[4,"hide-title"],"formAction":[32]}]);
const defineCustomElements = (opts) => {
  if (typeof customElements !== 'undefined') {
    [
      EbanxCookiesDisclaimer$1,
  EbanxLogo$1,
  EbanxTrackForm$1
    ].forEach(cmp => {
      if (!customElements.get(cmp.is)) {
        customElements.define(cmp.is, cmp, opts);
      }
    });
  }
};

export { EbanxCookiesDisclaimer$1 as EbanxCookiesDisclaimer, EbanxLogo$1 as EbanxLogo, EbanxTrackForm$1 as EbanxTrackForm, defineCustomElements };
